Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3741)

Unified Diff: ash/display/display_util.h

Issue 1261693004: Allow dynamic enabling/disabling of unified desktop (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/display/display_manager_unittest.cc ('k') | ash/display/display_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/display/display_util.h
diff --git a/ash/display/display_util.h b/ash/display/display_util.h
index dd0784bd8e6f8f32fda09ecd4c48faff396a1b9d..0e4dadf97d0cc0e39277c88ec0b71e1485295778 100644
--- a/ash/display/display_util.h
+++ b/ash/display/display_util.h
@@ -87,11 +87,15 @@ ASH_EXPORT int FindDisplayIndexContainingPoint(
const std::vector<gfx::Display>& displays,
const gfx::Point& point_in_screen);
// Creates the DisplayIdPair where ids are sorted in the following manner.
// 1) ID for internal display comes first.
// 2) If none of the ids are internal, sorted by the output index.
ASH_EXPORT DisplayIdPair CreateDisplayIdPair(int64 id1, int64 id2);
+// Returns true if one of following conditinos is met.
+// 1) id1 is internal.
+// 2) output index of id1 < output index of id2 and id2 isn't internal.
+ASH_EXPORT bool CompareDisplayIds(int64 id1, int64 id2);
+
} // namespace ash
#endif // ASH_DISPLAY_DISPLAY_UTIL_H_
« no previous file with comments | « ash/display/display_manager_unittest.cc ('k') | ash/display/display_util.cc » ('j') | no next file with comments »
@@ -87,11 +87,15 @@ ASH_EXPORT int FindDisplayIndexContainingPoint(
const std::vector<gfx::Display>& displays,
const gfx::Point& point_in_screen);
-// Creates the DisplayIdPair where ids are sorted in the following manner.
-// 1) ID for internal display comes first.
-// 2) If none of the ids are internal, sorted by the output index.
+// Creates the DisplayIdPair where ids are sorted using |CompareDisplayIds|
+// below.
ASH_EXPORT DisplayIdPair CreateDisplayIdPair(int64 id1, int64 id2);

Powered by Google App Engine
This is Rietveld 408576698